## AWS Roles

This repository manages IAM roles and role-policies with [Boto3 IAM client](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iam.html).


An `IAM role` is an IAM identity that you can create in your account that has specific permissions.

Check existence and create a `role policy` by
creating policies and attaching them to IAM identities.

- Role-policy documents must be provided in JSON format in IAM policies.
